==> react-object-1.0.1.tgz: package/lib/specs/Value.spec.js <==
"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

var _componentsValue = require("../components/Value");

var _componentsValue2 = _interopRequireDefault(_componentsValue);

var _jsUtilTest = require("js-util/test");

var _sections = require("./sections");

describe("Value", function () {
  var _this = this;

  this.header("## A single value of any type.");
  before(function () {
    var value = { foo: 123, bar: { baz: "hello" } };
    _this.align("top left").scroll(true).load(_react2["default"].createElement(_componentsValue2["default"], {
      label: "foo",
      value: value }));
  });

  section("`label`", function () {
    it("`null`", function () {
      return _this.props({ label: null });
    });
    it("`'foo'`", function () {
      return _this.props({ label: "foo" });
    });
  });

  section("showTwisty", function () {
    it("`true`", function () {
      return _this.props({ showTwisty: true });
    });
    it("`false`", function () {
      return _this.props({ showTwisty: false });
    });
    it("`undefined` (auto)", function () {
      return _this.props({ showTwisty: undefined });
    });
  });

  section("Primitive", function () {
    it("`string` short", function () {
      return _this.props({ value: "My String" });
    });
    it("`string` long", function () {
      return _this.props({ value: (0, _jsUtilTest.lorem)() });
    });
    it("`number: 123456`", function () {
      return _this.props({ value: 123456 });
    });
    it("`number: -1`", function () {
      return _this.props({ value: -1 });
    });
    it("`bool: true`", function () {
      return _this.props({ value: true });
    });
    it("`bool: false`", function () {
      return _this.props({ value: false });
    });
    it("`null`", function () {
      return _this.props({ value: null });
    });
    it("`undefined`", function () {
      return _this.props({ value: undefined });
    });
  });

  _sections.objectValueSection.call(this);
  _sections.arrayValueSection.call(this);

  section("Date", function () {
    it("`date: now`", function () {
      return _this.props({ value: new Date() });
    });
  });

  _sections.functionValueSection.call(this);
  _sections.italicSection.call(this);
  _sections.sizeSection.call(this);
});

==> react-object-1.0.6.tgz: package/lib/specs/Value.spec.js <==
"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

var _componentsValue = require("../components/Value");

var _componentsValue2 = _interopRequireDefault(_componentsValue);

var _jsUtilTest = require("js-util/test");

var _sections = require("./sections");

describe("Value", function () {
  var _this = this;

  this.header("## A single value of any type.");
  before(function () {
    var value = { foo: 123, bar: { baz: "hello" } };
    _this.align("top left").scroll(true).load(_react2["default"].createElement(_componentsValue2["default"], {
      label: "foo",
      value: value }));
  });

  section("label", function () {
    it("`null`", function () {
      return _this.props({ label: null });
    });
    it("`'foo'`", function () {
      return _this.props({ label: "foo" });
    });
  });

  section("showTwisty", function () {
    it("`true`", function () {
      return _this.props({ showTwisty: true });
    });
    it("`false`", function () {
      return _this.props({ showTwisty: false });
    });
    it("`undefined` (auto)", function () {
      return _this.props({ showTwisty: undefined });
    });
  });

  section("Primitive", function () {
    it("`string` short", function () {
      return _this.props({ value: "My String" });
    });
    it("`string` long", function () {
      return _this.props({ value: (0, _jsUtilTest.lorem)() });
    });
    it("`number: 123456`", function () {
      return _this.props({ value: 123456 });
    });
    it("`number: -1`", function () {
      return _this.props({ value: -1 });
    });
    it("`bool: true`", function () {
      return _this.props({ value: true });
    });
    it("`bool: false`", function () {
      return _this.props({ value: false });
    });
    it("`null`", function () {
      return _this.props({ value: null });
    });
    it("`undefined`", function () {
      return _this.props({ value: undefined });
    });
  });

  _sections.objectValueSection.call(this);
  _sections.arrayValueSection.call(this);

  section("Date", function () {
    it("`date: now`", function () {
      return _this.props({ value: new Date() });
    });
  });

  _sections.functionValueSection.call(this);
  _sections.italicSection.call(this);
  _sections.sizeSection.call(this);
  _sections.collapsedTotalSection.call(this);
});
